# abbreviation-uhh-what-is-word-for-tearing-apart-an-abbreviation
## or auwiwftaaa
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-green)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-blue)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-orange)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-yellow)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-red)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-pink)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-purple)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-white)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-black)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-teal)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-aquamarine)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-magenta)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-violet)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-indigo)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-silver)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-gold)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-beige)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-brown)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-gray)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-navy)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-brightgreen)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-yellowgreen)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-lightgray)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-blueviolet)
![Trivago hotel](https://img.shields.io/badge/hotel-Trivago-9cf)

i swear dont look
<br>
please
<br>
i just made this for my friend